==> haskell-wai-app-static-3.1.6.1-54-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-Gxv3XRmfz5KDrUG2TJNecW
key: wai-app-static-3.1.6.1-Gxv3XRmfz5KDrUG2TJNecW
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: dc970dba889a3975b4d648d130f6af53
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-Gxv3XRmfz5KDrUG2TJNecW
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.22-DUE2wxQoCnxGJxqhoLxB9Z
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-Jpd6oqB2FgfHxNuwDmOMO1
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    memory-0.14.5-8bv3NC3SoYTKu3JUzoaHbd
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    wai-3.2.1.1-Em8S4AXb0sj2I3tvlcNzHV
    wai-extra-3.0.19.1-8qR8KuAifyRBlGVDv84sTT
    warp-3.2.11.2-EzHUnnE1XXTF86QvCcHsJr
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.6.1-56-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-2yMAhjRp7qWEBqPdGDscNl
key: wai-app-static-3.1.6.1-2yMAhjRp7qWEBqPdGDscNl
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: 4f0bc2a4d812b4f4a9243024eb5b1329
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-2yMAhjRp7qWEBqPdGDscNl
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.22-BghVPg0sVunAfXbG7gt71d
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-Jpd6oqB2FgfHxNuwDmOMO1
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    memory-0.14.5-GKVoAxUgmX27c6UFr57XrL
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    wai-3.2.1.1-Em8S4AXb0sj2I3tvlcNzHV
    wai-extra-3.0.19.1-8qR8KuAifyRBlGVDv84sTT
    warp-3.2.12-JirNNL9JkiY5scISkptQgX
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
